.. signaturesimulator documentation master file, created by
   sphinx-quickstart on Tue Feb 27 08:27:00 2018.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to signaturesimulator's documentation!
==============================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   _source/README.rst



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
